@@ -1,7 +1,7 @@
 """
    SDC Client model module
 """
-from sqlalchemy import Column, Integer, String, DateTime, JSON
+from sqlalchemy import Column, String, DateTime, JSON
 from sqlalchemy.orm import relationship
 from sdc_helpers.models.model import Model
 from sdc_helpers.models.subscription import Subscription
@@ -13,11 +13,11 @@ class Client(Model):
     # pylint: disable=too-few-public-methods
     __tablename__ = 'clients'
 
-    id = Column(Integer, primary_key=True)
     code = Column(String(255), unique=True)
     name = Column(String(255))
     properties = Column(JSON)
     last_login_at = Column(DateTime)
+    deleted_at = Column(DateTime)
     updated_by = Column(String(255))
     subscriptions = relationship(Subscription)
 
